import { Svg, Path, LinearGradient, Stop, Defs, Mask, Polygon } from 'react-native-svg';
import { assets } from './assets';
import { getHexagonPoints, getOctagonPoints, getSquarePoints } from './utils';
import React from 'react';
const Crypto = _ref => {
  let {
    name = 'btc',
    size = 24,
    shape = 'circular',
    tilt = false
  } = _ref;
  const {
    viewBox,
    paths
  } = assets[name];
  if (!paths) return null;
  const hexagonPoints = getHexagonPoints(viewBox, tilt);
  const octagonPoints = getOctagonPoints(viewBox, tilt);
  const squarePoints = getSquarePoints(viewBox, tilt);
  let maskId;
  let maskPoints = '';
  switch (shape) {
    case 'hexagonal':
      maskId = 'hexagonMask';
      maskPoints = hexagonPoints;
      break;
    case 'octagonal':
      maskId = 'octagonMask';
      maskPoints = octagonPoints;
      break;
    case 'square':
      maskId = 'squareMask';
      maskPoints = squarePoints;
      break;
  }
  return /*#__PURE__*/React.createElement(Svg, {
    width: size,
    height: size,
    viewBox: `0 0 ${viewBox} ${viewBox}`,
    fill: "none"
  }, /*#__PURE__*/React.createElement(Defs, null, maskId && /*#__PURE__*/React.createElement(Mask, {
    id: maskId
  }, /*#__PURE__*/React.createElement(Polygon, {
    points: maskPoints,
    fill: "white"
  })), paths.map((item, idx) => {
    if (item.gradient) {
      return /*#__PURE__*/React.createElement(LinearGradient, {
        key: `gradient${idx}`,
        id: `gradient${idx}`,
        x1: item.gradient.x1 / viewBox,
        y1: item.gradient.y1 / viewBox,
        x2: item.gradient.x2 / viewBox,
        y2: item.gradient.y2 / viewBox
      }, item.gradient.stops.map((stop, stopIdx) => /*#__PURE__*/React.createElement(Stop, {
        key: stopIdx,
        stopColor: stop.color,
        offset: stop.offset !== null ? stop.offset : '0',
        stopOpacity: stop.stopOpacity !== undefined ? stop.stopOpacity : 1
      })));
    } else return null;
  })), paths.map((item, idx) => /*#__PURE__*/React.createElement(Path, {
    key: idx,
    d: item.path,
    fill: item.gradient ? `url(#gradient${idx})` : item.fill,
    opacity: item.opacity !== undefined ? item.opacity : 1,
    fillRule: "evenodd",
    clipRule: "evenodd",
    mask: maskId ? `url(#${maskId})` : undefined
  })));
};
export default Crypto;
//# sourceMappingURL=Crypto.js.map